@@ -118,9 +118,9 @@ void Akonadi::DataStore::close()
 
 bool Akonadi::DataStore::init()
 {
-  DbInitializer initializer( m_database, QLatin1String(":akonadidb.xml") );
-  if (! initializer.run() ) {
-    akError() << initializer.errorMsg();
+  DbInitializer::Ptr initializer = DbInitializer::createInstance( m_database, QLatin1String(":akonadidb.xml") );
+  if (! initializer->run() ) {
+    akError() << initializer->errorMsg();
     return false;
   }
 
@@ -495,7 +495,7 @@ bool DataStore::cleanupPimItems( const Collection &collection )
 
   qb.addColumn( PimItemFlagRelation::leftFullColumnName() );
 
-  qb.addValueCondition( Flag::nameFullColumnName(), Query::Equals, QLatin1String("\\Deleted") );
+  qb.addValueCondition( Flag::nameFullColumnName(), Query::Equals, QLatin1String("\\DELETED") );
   qb.addValueCondition( PimItem::collectionIdFullColumnName(), Query::Equals, collection.id() );
 
   if ( !qb.exec() )
